Inode slimming patches, part 1
Get series with b4
b4 am [email protected]Versions newest first
- v1 Latest8 patches 8 repliesIn review
Patches in v1 No applies recorded yet
| # | Subject and files | Size | Replies | Applied |
|---|---|---|---|---|
| 1/8 | inode_diet: Replace inode.u.generic_ip with inode.i_privatearch/ arch/ arch/ +43 more | +120 | 0 replies | |
| 2/8 | inode-diet: Move i_pipe into a unioninclude/ | +3 | 0 replies | |
| 3/8 | inode-diet: Move i_bdev into a unionfs/ include/ | +2 | 0 replies | |
| 4/8 | inode-diet: Move i_cdev into a unionfs/ fs/ include/ | +3 | 0 replies | |
| 5/8 | inode-diet: Eliminate i_blksize and use a per-superblock defaultarch/ arch/ drivers/ +80 more | +21 | 0 replies | |
| 6/8 | inode-diet: Move i_cindex from struct inode to struct filedrivers/ fs/ include/ | +3 | 2 replies | |
| 7/8 | inode-diet: Use a union for i_blocks and i_size, i_rdev and i_devicesfs/ include/ | +13 | 6 replies | |
| 8/8 | inode-diet: Fix size of i_blkbits, i_version, and i_dnotify_maskinclude/ | +3 | 0 replies |
Reviews trailers per patch
No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.
Cover letter [patch 0/8] Inode slimming patches, part 1
The following patches are against 2.6.17-mm5, and reduce the size of the VFS inode structure by 28 bytes on a UP x86. (It would be more on an x86_64 system). This is a 10% reduction in the inode size on a UP kernel that is configured in a production mode (i.e., with no spinlock or other debugging functions enabled; if you want to save memory taken up by in-core inodes, the first thing you should do is disable the debugging options; they are responsible for a huge amount of bloat in the VFS inode structure).
- Ted